#################################################################
#                                                               #
# Wilfred                                                       #
# Copyright (C) 2020-2022, Vilhelm Prytz, <vilhelm@prytznet.se> #
#                                                               #
# Licensed under the terms of the MIT license, see LICENSE.     #
# https://github.com/wilfred-dev/wilfred                        #
#                                                               #
#################################################################

# use "0.0.0.dev0" to indicate incremental commit build
# specify version "0.3.0" to indicate standard release
# "commit_date" should be replaced upon building
version = "0.10.1"
commit_hash = "cfa76bca4e0520c98e169d3246411367ab5e42a8"
commit_date = "2022-05-08"
